==> gsequencer-4.5.3.tar.gz: gsequencer-4.5.3/clean-gtk-doc.sh <==
#!/bin/bash
# 
# Copyright (C) 2005-2020 Joël Krähemann
# 
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.

rm -rf docs/reference/libags-audio/.libs/
rm -f docs/reference/libags-audio/html-build.stamp
rm -f docs/reference/libags-audio/html.stamp
rm -f docs/reference/libags-audio/libags_audio.actions
rm -f docs/reference/libags-audio/libags_audio-decl-list.txt
rm -f docs/reference/libags-audio/libags_audio-decl-list.txt.bak
rm -f docs/reference/libags-audio/libags_audio-decl.txt
rm -f docs/reference/libags-audio/libags_audio-decl.txt.bak
rm -f docs/reference/libags-audio/libags_audio-undeclared.txt
rm -f docs/reference/libags-audio/libags_audio-undocumented.txt
rm -f docs/reference/libags-audio/libags_audio-unused.txt
rm -f docs/reference/libags-audio/libags_audio.args
rm -f docs/reference/libags-audio/libags_audio.hierarchy
rm -f docs/reference/libags-audio/libags_audio.pdf
rm -f docs/reference/libags-audio/libags_audio.prerequisites
rm -f docs/reference/libags-audio/libags_audio.signals
rm -f docs/reference/libags-audio/libags_audio.types.bak
rm -f docs/reference/libags-audio/pdf.stamp
rm -f docs/reference/libags-audio/pdf-build.stamp
rm -f docs/reference/libags-audio/scan-build.stamp
rm -f docs/reference/libags-audio/setup-build.stamp
rm -f docs/reference/libags-audio/sgml-build.stamp
rm -f docs/reference/libags-audio/sgml.stamp
rm -rf docs/reference/libags-gui/.libs/
rm -f docs/reference/libags-gui/html-build.stamp
rm -f docs/reference/libags-gui/html.stamp
rm -f docs/reference/libags-gui/libags_gui.actions
rm -f docs/reference/libags-gui/libags_gui-decl-list.txt
rm -f docs/reference/libags-gui/libags_gui-decl.txt
rm -f docs/reference/libags-gui/libags_gui-undeclared.txt
rm -f docs/reference/libags-gui/libags_gui-undocumented.txt
rm -f docs/reference/libags-gui/libags_gui-unused.txt
rm -f docs/reference/libags-gui/libags_gui.args
rm -f docs/reference/libags-gui/libags_gui.hierarchy
rm -f docs/reference/libags-gui/libags_gui.pdf
rm -f docs/reference/libags-gui/libags_gui.prerequisites
rm -f docs/reference/libags-gui/libags_gui.signals
rm -f docs/reference/libags-gui/scan-build.stamp
rm -f docs/reference/libags-gui/pdf.stamp
rm -f docs/reference/libags-gui/pdf-build.stamp
rm -f docs/reference/libags-gui/setup-build.stamp
rm -f docs/reference/libags-gui/sgml-build.stamp
rm -f docs/reference/libags-gui/sgml.stamp
rm -rf docs/reference/libags/.libs/
rm -f docs/reference/libags/libags.actions
rm -f docs/reference/libags/html-build.stamp
rm -f docs/reference/libags/html.stamp
rm -f docs/reference/libags/libags-decl-list.txt
rm -f docs/reference/libags/libags-decl.txt
rm -f docs/reference/libags/libags-undeclared.txt
rm -f docs/reference/libags/libags-undocumented.txt
rm -f docs/reference/libags/libags-unused.txt
rm -f docs/reference/libags/libags.args
rm -f docs/reference/libags/libags.hierarchy
rm -f docs/reference/libags/libags.prerequisites
rm -f docs/reference/libags/libags.signals
rm -f docs/reference/libags/libags.types.bak
rm -f docs/reference/libags/scan-build.stamp
rm -f docs/reference/libags/setup-build.stamp
rm -f docs/reference/libags/sgml-build.stamp
rm -f docs/reference/libags/sgml.stamp
rm -rf docs/reference/libgsequencer/.libs/
rm -f docs/reference/libgsequencer/html-build.stamp
rm -f docs/reference/libgsequencer/html.stamp
rm -f docs/reference/libgsequencer/libgsequencer-decl-list.txt
rm -f docs/reference/libgsequencer/libgsequencer-decl.txt
rm -f docs/reference/libgsequencer/libgsequencer-undeclared.txt
rm -f docs/reference/libgsequencer/libgsequencer-undocumented.txt
rm -f docs/reference/libgsequencer/libgsequencer-unused.txt
rm -f docs/reference/libgsequencer/libgsequencer.args
rm -f docs/reference/libgsequencer/libgsequencer.hierarchy
rm -f docs/reference/libgsequencer/libgsequencer.pdf
rm -f docs/reference/libgsequencer/libgsequencer.prerequisites
rm -f docs/reference/libgsequencer/libgsequencer.signals
rm -f docs/reference/libgsequencer/libgsequencer.types.bak
rm -f docs/reference/libgsequencer/pdf.stamp
rm -f docs/reference/libgsequencer/pdf-build.stamp
rm -f docs/reference/libgsequencer/scan-build.stamp
rm -f docs/reference/libgsequencer/setup-build.stamp
rm -f docs/reference/libgsequencer/sgml-build.stamp
rm -f docs/reference/libgsequencer/sgml.stamp
rm -f docs/reference/libgsequencer/libgsequencer.actions

==> gsequencer_7.7.5.orig.tar.gz: gsequencer-7.7.5/clean-gtk-doc.sh <==
#!/bin/bash
# 
# Copyright (C) 2005-2020 Joël Krähemann
# 
# Copying and distribution of this file, with or without modification,
# are permitted in any medium without royalty provided the copyright
# notice and this notice are preserved.  This file is offered as-is,
# without any warranty.

rm -rf docs/reference/libags-audio/.libs/
rm -f docs/reference/libags-audio/html-build.stamp
rm -f docs/reference/libags-audio/html.stamp
rm -f docs/reference/libags-audio/libags_audio.actions
rm -f docs/reference/libags-audio/libags_audio-decl-list.txt
rm -f docs/reference/libags-audio/libags_audio-decl-list.txt.bak
rm -f docs/reference/libags-audio/libags_audio-decl.txt
rm -f docs/reference/libags-audio/libags_audio-decl.txt.bak
rm -f docs/reference/libags-audio/libags_audio-undeclared.txt
rm -f docs/reference/libags-audio/libags_audio-undocumented.txt
rm -f docs/reference/libags-audio/libags_audio-unused.txt
rm -f docs/reference/libags-audio/libags_audio.args
rm -f docs/reference/libags-audio/libags_audio.hierarchy
rm -f docs/reference/libags-audio/libags_audio.pdf
rm -f docs/reference/libags-audio/libags_audio.prerequisites
rm -f docs/reference/libags-audio/libags_audio.signals
rm -f docs/reference/libags-audio/libags_audio.types.bak
rm -f docs/reference/libags-audio/pdf.stamp
rm -f docs/reference/libags-audio/pdf-build.stamp
rm -f docs/reference/libags-audio/scan-build.stamp
rm -f docs/reference/libags-audio/setup-build.stamp
rm -f docs/reference/libags-audio/sgml-build.stamp
rm -f docs/reference/libags-audio/sgml.stamp
rm -rf docs/reference/libags-gui/.libs/
rm -f docs/reference/libags-gui/html-build.stamp
rm -f docs/reference/libags-gui/html.stamp
rm -f docs/reference/libags-gui/libags_gui.actions
rm -f docs/reference/libags-gui/libags_gui-decl-list.txt
rm -f docs/reference/libags-gui/libags_gui-decl.txt
rm -f docs/reference/libags-gui/libags_gui-undeclared.txt
rm -f docs/reference/libags-gui/libags_gui-undocumented.txt
rm -f docs/reference/libags-gui/libags_gui-unused.txt
rm -f docs/reference/libags-gui/libags_gui.args
rm -f docs/reference/libags-gui/libags_gui.hierarchy
rm -f docs/reference/libags-gui/libags_gui.pdf
rm -f docs/reference/libags-gui/libags_gui.prerequisites
rm -f docs/reference/libags-gui/libags_gui.signals
rm -f docs/reference/libags-gui/scan-build.stamp
rm -f docs/reference/libags-gui/pdf.stamp
rm -f docs/reference/libags-gui/pdf-build.stamp
rm -f docs/reference/libags-gui/setup-build.stamp
rm -f docs/reference/libags-gui/sgml-build.stamp
rm -f docs/reference/libags-gui/sgml.stamp
rm -rf docs/reference/libags/.libs/
rm -f docs/reference/libags/libags.actions
rm -f docs/reference/libags/html-build.stamp
rm -f docs/reference/libags/html.stamp
rm -f docs/reference/libags/libags-decl-list.txt
rm -f docs/reference/libags/libags-decl.txt
rm -f docs/reference/libags/libags-undeclared.txt
rm -f docs/reference/libags/libags-undocumented.txt
rm -f docs/reference/libags/libags-unused.txt
rm -f docs/reference/libags/libags.args
rm -f docs/reference/libags/libags.hierarchy
rm -f docs/reference/libags/libags.pdf
rm -f docs/reference/libags/libags.prerequisites
rm -f docs/reference/libags/libags.signals
rm -f docs/reference/libags/libags.types.bak
rm -f docs/reference/libags/pdf.stamp
rm -f docs/reference/libags/pdf-build.stamp
rm -f docs/reference/libags/scan-build.stamp
rm -f docs/reference/libags/setup-build.stamp
rm -f docs/reference/libags/sgml-build.stamp
rm -f docs/reference/libags/sgml.stamp
rm -rf docs/reference/libgsequencer/.libs/
rm -f docs/reference/libgsequencer/html-build.stamp
rm -f docs/reference/libgsequencer/html.stamp
rm -f docs/reference/libgsequencer/libgsequencer-decl-list.txt
rm -f docs/reference/libgsequencer/libgsequencer-decl.txt
rm -f docs/reference/libgsequencer/libgsequencer-undeclared.txt
rm -f docs/reference/libgsequencer/libgsequencer-undocumented.txt
rm -f docs/reference/libgsequencer/libgsequencer-unused.txt
rm -f docs/reference/libgsequencer/libgsequencer.args
rm -f docs/reference/libgsequencer/libgsequencer.hierarchy
rm -f docs/reference/libgsequencer/libgsequencer.pdf
rm -f docs/reference/libgsequencer/libgsequencer.prerequisites
rm -f docs/reference/libgsequencer/libgsequencer.signals
rm -f docs/reference/libgsequencer/libgsequencer.types.bak
rm -f docs/reference/libgsequencer/pdf.stamp
rm -f docs/reference/libgsequencer/pdf-build.stamp
rm -f docs/reference/libgsequencer/scan-build.stamp
rm -f docs/reference/libgsequencer/setup-build.stamp
rm -f docs/reference/libgsequencer/sgml-build.stamp
rm -f docs/reference/libgsequencer/sgml.stamp
rm -f docs/reference/libgsequencer/libgsequencer.actions
